import subprocess
import logging
import re
import os

from shutil import copytree

script_dir = os.path.dirname(os.path.realpath(__file__))
basedir = os.path.realpath(os.path.join(script_dir, ".."))
static_dir = os.path.realpath(os.path.join(basedir, "www/static/"))
assets_dir = os.path.realpath(os.path.join(basedir, "assets"))
regex = re.compile(ur'(\d+) static files copied')


def collect_static():
    output = subprocess.check_output(
        ['python', 'manage.py', 'collectstatic', '--noinput']
    )
    match = regex.search(output)
    if not match:
        print("Invalid response from collectstatic... exiting...")
    elif output[1] != '0':
        revno = int(subprocess.check_output(['bzr', 'revno'], cwd=basedir)) + 1
        new_dir = 'r' + str(revno)
        subprocess.check_call(
            [
                'bzr',
                'up',
            ],
            cwd=assets_dir,
        )
        new_dir_path = os.path.join(assets_dir, new_dir)
        copytree(static_dir, new_dir_path)
        subprocess.check_call(['bzr', 'add', new_dir], cwd=assets_dir)
        commit_msg = '"Dashboard commit ' + new_dir + '"'
        subprocess.check_call(
            [
                'bzr',
                'commit',
                '-m',
                commit_msg,
            ],
            cwd=assets_dir,
        )
        _write_assets_revision(new_dir)


def _write_assets_revision(revno):
    file_name = os.path.join(basedir, "assets_revision.py")
    if os.path.exists(file_name):
        os.remove(file_name)
    with open(file_name, 'w') as f:
        f.write("""revision = '%s'""" % revno)

if __name__ == "__main__":
    try:
        collect_static()
    except Exception as e:
        logging.error(e)
