# QA Dashboard

# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

import json

from django.views.decorators.http import require_GET

from common.utils import (
    JSONResponse,
    MySerializer,
)

from suspend.models import (
    SuspendImage,
    SuspendResult,
)


@require_GET
def images(request, arch=None):
    images = SuspendImage.objects.filter(
        publish=True,
    )

    if arch:
        images = images.filter(arch=arch)

    serializer = MySerializer(use_extra_fields=False)
    data = serializer.serialize(images)

    return JSONResponse(data)


@require_GET
def results(request, image_id=None):

    results = SuspendResult.objects.filter(
        publish=True,
        image__id=image_id,
    )

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize(results)

    return JSONResponse(data)


@require_GET
def machine_overview(request, machine_id):
    IMAGE_COUNT=60

    results = list(SuspendResult.objects.filter(
        publish=True,
        machine__id=machine_id,
    ).order_by(
        'image__build_id',
        'image__rootfs_id',
        'image__device_specific_id',
        'image__customization_id',
        'image__build_number',
    ).values(
        'image__build_id',
        'image__rootfs_id',
        'image__device_specific_id',
        'image__customization_id',
        'image__build_number',
        'suspend_mean_duration_seconds',
        'suspend_minimum_duration_seconds',
        'suspend_maximum_duration_seconds',
        'awake_minimum_duration_seconds',
        'awake_maximum_duration_seconds',
        'suspends_attempted',
        'suspends_succeeded_percent',
        'suspends_total_time_percent',
    ))[-IMAGE_COUNT:]

    data = json.dumps(results)

    return JSONResponse(data)
