# QA Dashboard
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models

from common.models import (
    DashboardBaseModel,
    JenkinsBuild,
)

from performance.models import (
    ImageBase,
    MachineBase,
)


class SuspendImage(ImageBase):

    class Meta:
        db_table = 'suspend_images'


class SuspendMachine(MachineBase):

    class Meta:
        db_table = "suspend_machines"


class SuspendResult(DashboardBaseModel):

    class Meta:
        db_table = 'suspend_results'

    image = models.ForeignKey(SuspendImage)
    machine = models.ForeignKey(SuspendMachine)
    jenkins_build = models.ForeignKey(JenkinsBuild)

    suspends_attempted = models.IntegerField(null=True, blank=True)
    suspends_succeeded_percent = models.FloatField(null=True, blank=True)
    suspends_total_time_percent = models.FloatField(null=True, blank=True)
    suspend_mean_duration_seconds = models.FloatField(null=True, blank=True)
    suspend_minimum_duration_seconds = models.FloatField(null=True, blank=True)
    suspend_maximum_duration_seconds = models.FloatField(null=True, blank=True)
    awake_minimum_duration_seconds = models.FloatField(null=True, blank=True)
    awake_maximum_duration_seconds = models.FloatField(null=True, blank=True)


class SuspendBlocker(DashboardBaseModel):

    class Meta:
        db_table = "suspend_blockers"

    result = models.ForeignKey(SuspendResult)
    name = models.CharField(max_length=4096)
    count = models.IntegerField(null=True, blank=True)
    percent = models.FloatField(null=True, blank=True)
