# QA Dashboard
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables
from django_tables2.utils import Accessor as A

from suspend.models import (
    SuspendImage,
)


class SuspendImageTable(tables.Table):
    class Meta:
        attrs = {'class': 'basic wide'}
        model = SuspendImage
        fields = (
            'build_number',
            'release',
            'arch',
            'suspend_mean',
            'total_time',
        )
        order_by = (
            '-release',
            'variant',
            '-rootfs_id',
            '-build_id',
            '-device_specific_id',
            '-customization_id',
            '-build_number',
        )

    build_number = tables.LinkColumn(
        "suspend_result_details",
        kwargs={
            "pk": A("id"),
        },
        order_by=(
            '-release',
            'variant',
            '-rootfs_id',
            '-build_id',
            '-device_specific_id',
            '-customization_id',
            '-build_number',
        ),
    )

    suspend_mean = tables.TemplateColumn(
        "{{ record.suspendresult_set.all.0."
        "suspend_mean_duration_seconds|floatformat }}",
        verbose_name="Suspend mean duration",
        attrs={'td': {'class': 'num'}},
    )

    total_time = tables.TemplateColumn(
        "{{ record.suspendresult_set.all.0."
        "suspends_total_time_percent|floatformat:2 }}",
        verbose_name="Total time (%)",
        attrs={'td': {'class': 'num'}},
    )
