# QA Dashboard
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import render_to_response
from django.template import RequestContext
from django.views.decorators.http import require_GET
from django.views.generic import DetailView
from django_tables2 import RequestConfig

from common.bread_crumbs import (
    BreadCrumb,
    BreadCrumbTrail,
)

from suspend.models import SuspendImage
from suspend.tables import (
    SuspendImageTable,
)
from suspend.utils import (
    get_arches,
    get_images,
    get_machines,
)

DEFAULT_ARCH = "armhf"


@BreadCrumb("Suspend blockers")
@require_GET
def arch_overview(request, arch=None):

    arches = get_arches()

    if not arch:
        if len(arches) > 0:
            arch = arches[0]
        else:
            arch = DEFAULT_ARCH

    images = get_images(arch)
    machines = get_machines(arch)

    data = {
        'arch': arch,
        'arches': arches,
        'images': images,
        'machines': machines,
        'bread_crumb_trail': BreadCrumbTrail.leading_to(arch_overview),
    }

    return render_to_response(
        'suspend/arch_overview.html',
        data,
        RequestContext(request),
    )


@BreadCrumb(
    "Image overview",
    parent=arch_overview,
    needs=['arch'],
)
@require_GET
def image_overview(request, arch):
    arches = get_arches()
    images = SuspendImage.objects.filter(
        publish=True,
        arch=arch,
    )

    table = SuspendImageTable(images, order_by=(
        '-release',
        'variant',
        'rootfs_id',
        'build_id',
        'device_specific_id',
        'customization_id',
        'build_number'))
    RequestConfig(request, paginate=None).configure(table)

    data = dict(
        table=table,
        images=images,
        arch=arch,
        arches=arches,
        bread_crumb_trail=BreadCrumbTrail.leading_to(arch_overview),
    )

    return render_to_response(
        'suspend/image_overview.html',
        data,
        RequestContext(request),
    )


class ImageView(DetailView):

    def get_context_data(self, **kwargs):
        context = super(ImageView, self).get_context_data(**kwargs)
        context['arches'] = get_arches()
        context['arch'] = self.object.arch
        context['bread_crumb_trail'] = (
            BreadCrumbTrail.leading_to(image_overview, arch=self.object.arch)
        )

        return context
